Chapter 4: Pixelizations
========================

In chapter 4, we use **Pixelizations** to reconstruct complex source galaxies on pixelized grids.

The chapter contains the following tutorials:

`Tutorial 1: Pixelizations <https://mybinder.org/v2/gh/Jammy2211/autolens_workspace/release?filepath=notebooks/howtolens/chapter_4_pixelizations/tutorial_1_pixelizations.ipynb>`_
- Creating a pixel-grid in the source-plane.

`Tutorial 2: Mappers <https://mybinder.org/v2/gh/Jammy2211/autolens_workspace/release?filepath=notebooks/howtolens/chapter_4_pixelizations/tutorial_2_mappers.ipynb>`_
- How a pixelization maps source-pixels to image-pixels.

`Tutorial 3: Inversions <https://mybinder.org/v2/gh/Jammy2211/autolens_workspace/release?filepath=notebooks/howtolens/chapter_4_pixelizations/tutorial_3_inversions.ipynb>`_
- Inverting the mappings to reconstruct the source's light.

`Tutorial 4: Bayesian Regularization <https://mybinder.org/v2/gh/Jammy2211/autolens_workspace/release?filepath=notebooks/howtolens/chapter_4_pixelizations/tutorial_4_bayesian_regularization.ipynb>`_
- Smoothing the source within a Bayesian framework.

`Tutorial 5: Borders <https://mybinder.org/v2/gh/Jammy2211/autolens_workspace/release?filepath=notebooks/howtolens/chapter_4_pixelizations/tutorial_5_borders.ipynb>`_
- Preventing highly demagnified image-pixels ruining the inversion.

`Tutorial 6: Lens Modeling  <https://mybinder.org/v2/gh/Jammy2211/autolens_workspace/release?filepath=notebooks/howtolens/chapter_4_pixelizations/tutorial_6_lens_modeling.ipynb>`_
- How to use inversions to fit a lens model.

`Tutorial 7: Adaptive Pixelization <https://mybinder.org/v2/gh/Jammy2211/autolens_workspace/release?filepath=notebooks/howtolens/chapter_4_pixelizations/tutorial_7_adaptive_pixelization.ipynb>`_
- A Voronoi mesh which adapts to the mass model's magnification.

`Tutorial 8: Model Fit <https://mybinder.org/v2/gh/Jammy2211/autolens_workspace/release?filepath=notebooks/howtolens/chapter_4_pixelizations/tutorial_8_model_fit.ipynb>`_
- An example lens modeling pipeline which uses an inversion.

`Tutorial 9: Fit Problems <https://mybinder.org/v2/gh/Jammy2211/autolens_workspace/release?filepath=notebooks/howtolens/chapter_4_pixelizations/tutorial_9_fit_problems.ipynb>`_
- The shortcomings of our lens models and inversions.

`Tutorial 10: Brightness Adaption <https://mybinder.org/v2/gh/Jammy2211/autolens_workspace/release?filepath=notebooks/howtolens/chapter_4_pixelizations/tutorial_10_brightness_adaption.ipynb>`_
- Adapting the pixelization to the source's morphology.

`Tutorial 11: Adaptive Regularization <https://mybinder.org/v2/gh/Jammy2211/autolens_workspace/release?filepath=notebooks/howtolens/chapter_4_pixelizations/tutorial_11_adaptive_regularization.py.ipynb>`_
- Adapting the regularization to the source's morphology.